@@ -13,10 +13,13 @@ from .themes import *               # noqa: F401,F403,E261
 from .positions import *            # noqa: F401,F403,E261
 from .guides import *               # noqa: F401,F403,E261
 
-from ._version import get_versions
+from importlib.metadata import version, PackageNotFoundError
 
-__version__ = get_versions()['version']
-del get_versions
+try:
+    __version__ = version('plotnine')
+except PackageNotFoundError:
+    # package is not installed
+    pass
 
 
 def _get_all_imports():
