@@ -1,11 +1,12 @@
-from copy import deepcopy, copy
 import itertools
+import types
+from copy import deepcopy, copy
 from contextlib import suppress
 from warnings import warn
 
 import numpy as np
 import pandas as pd
-import types
+import pandas.api.types as pdtypes
 
 from .strips import strips
 from ..utils import cross_join, match
@@ -15,6 +16,7 @@ from ..scales.scales import Scales
 # For default matplotlib backend
 with suppress(ImportError):
     from matplotlib.ticker import locale, FixedFormatter
+    from matplotlib.gridspec import GridSpec
 
 
 class facet:
@@ -82,6 +84,10 @@ class facet:
     plot = None
     # Facet strips
     strips = None
+    # Control the relative size of multiple facets
+    # Use a subclass to change the default.
+    # See: facet_grid for an example
+    space = 'fixed'
 
     def __init__(self, scales='fixed', shrink=True,
                  labeller='label_value', as_table=True,
@@ -110,9 +116,9 @@ class facet:
                 setattr(self, name, value)
             else:
                 raise AttributeError(
-                    "{!r} object has no attribute {}".format(
-                        self.__class__.__name__,
-                        name))
+                    f"{self.__class__.__name__} object has "
+                    f"no attribute {name}"
+                )
 
     def setup_data(self, data):
         """
@@ -262,39 +268,26 @@ class facet:
         ax.set_xlim(panel_params.x.range)
         ax.set_ylim(panel_params.y.range)
 
-        # breaks
-        ax.set_xticks(panel_params.x.breaks)
-        ax.set_yticks(panel_params.y.breaks)
+        # breaks, labels
+        ax.set_xticks(panel_params.x.breaks, panel_params.x.labels)
+        ax.set_yticks(panel_params.y.breaks, panel_params.y.labels)
 
         # minor breaks
         ax.set_xticks(panel_params.x.minor_breaks, minor=True)
         ax.set_yticks(panel_params.y.minor_breaks, minor=True)
 
-        # labels
-        ax.set_xticklabels(panel_params.x.labels)
-        ax.set_yticklabels(panel_params.y.labels)
-
         # When you manually set the tick labels MPL changes the locator
         # so that it no longer reports the x & y positions
         # Fixes https://github.com/has2k1/plotnine/issues/187
         ax.xaxis.set_major_formatter(MyFixedFormatter(panel_params.x.labels))
         ax.yaxis.set_major_formatter(MyFixedFormatter(panel_params.y.labels))
 
-        get_property = self.theme.themeables.property
-        # Padding between ticks and text
-        try:
-            margin = get_property('axis_text_x', 'margin')
-        except KeyError:
-            pad_x = 2.4
-        else:
-            pad_x = margin.get_as('t', 'pt')
+        _property = self.theme.themeables.property
+        margin = _property('axis_text_x', 'margin')
+        pad_x = margin.get_as('t', 'pt')
 
-        try:
-            margin = get_property('axis_text_y', 'margin')
-        except KeyError:
-            pad_y = 2.4
-        else:
-            pad_y = margin.get_as('r', 'pt')
+        margin = _property('axis_text_y', 'margin')
+        pad_y = margin.get_as('r', 'pt')
 
         ax.tick_params(axis='x', which='major', pad=pad_x)
         ax.tick_params(axis='y', which='major', pad=pad_y)
@@ -326,12 +319,48 @@ class facet:
         """
         num_panels = len(layout)
         axsarr = np.empty((self.nrow, self.ncol), dtype=object)
+        space = self.space
+        default_space = {
+            'x': [1 for x in range(self.ncol)],
+            'y': [1 for x in range(self.nrow)],
+        }
+
+        if isinstance(space, str):
+            if space == 'fixed':
+                space = default_space
+            # TODO: Implement 'free', 'free_x' & 'free_y'
+            else:
+                space = default_space
+        elif isinstance(space, dict):
+            if 'x' not in space:
+                space['x'] = default_space['x']
+            if 'y' not in space:
+                space['y'] = default_space['y']
+
+        if len(space['x']) != self.ncol:
+            raise ValueError(
+                "The number of x-ratios for the facet space sizes "
+                "should match the number of columns."
+            )
+
+        if len(space['y']) != self.nrow:
+            raise ValueError(
+                "The number of y-ratios for the facet space sizes "
+                "should match the number of rows."
+            )
+
+        gs = GridSpec(
+            self.nrow,
+            self.ncol,
+            height_ratios=space['y'],
+            width_ratios=space['x']
+        )
 
         # Create axes
         i = 1
         for row in range(self.nrow):
             for col in range(self.ncol):
-                axsarr[row, col] = fig.add_subplot(self.nrow, self.ncol, i)
+                axsarr[row, col] = fig.add_subplot(gs[i - 1])
                 i += 1
 
         # Rearrange axes
@@ -367,6 +396,21 @@ class facet:
         self.axs = axs
         return axs
 
+    def _aspect_ratio(self):
+        "Return the aspect_ratio"
+        aspect_ratio = self.theme.themeables.property('aspect_ratio')
+        if aspect_ratio == 'auto':
+            # If the panels have different limits the coordinates
+            # cannot compute a common aspect ratio
+            if not self.free['x'] and not self.free['y']:
+                aspect_ratio = self.coordinates.aspect(
+                    self.layout.panel_params[0]
+                )
+            else:
+                aspect_ratio = None
+
+        return aspect_ratio
+
     def spaceout_and_resize_panels(self):
         """
         Adjust the spacing between the panels and resize them
@@ -443,7 +487,7 @@ def combine_vars(data, environment=None, vars=None, drop=True):
         ].drop_duplicates()
         if not drop:
             new = unique_combs(new)
-        base = base.append(cross_join(old, new), ignore_index=True)
+        base = pd.concat(base, cross_join(old, new), ignore_index=True)
 
     if len(base) == 0:
         raise PlotnineError(
@@ -458,8 +502,13 @@ def unique_combs(df):
     Return data frame with all possible combinations
     of the values in the columns
     """
+    def _unique(s):
+        if isinstance(s.dtype, pdtypes.CategoricalDtype):
+            return s.cat.categories
+        return s.unique()
+
     # List of unique values from every column
-    lst = (x.unique() for x in (df[c] for c in df))
+    lst = (_unique(x) for _, x in df.iteritems())
     rows = list(itertools.product(*lst))
     _df = pd.DataFrame(rows, columns=df.columns)
 
@@ -482,7 +531,7 @@ def add_missing_facets(data, layout, vars, facet_vals):
     # the facet variables, add the missing facet variables
     # and create new data where the points(duplicates) are
     # present in all the facets
-    missing_facets = set(vars) - set(facet_vals)
+    missing_facets = list(set(vars) - set(facet_vals))
     if missing_facets:
         to_add = layout.loc[:, missing_facets].drop_duplicates()
         to_add.reset_index(drop=True, inplace=True)
