@@ -38,11 +38,27 @@ class facet_grid(facet):
         to vary according to the data along rows or columns.
         Default is ``'fixed'``, the same scales for all the
         panels.
-    space : str in ``['fixed', 'free', 'free_x', 'free_y']``
-        Whether the ``x`` or ``y`` sides of the panels
-        should have the size. It also depends to the
-        ``scales`` parameter. Default is ``'fixed'``.
-        This setting is not yet supported.
+    space : str | dict
+        Control the size of the  ``x`` or ``y`` sides of the panels.
+        The size also depends to the ``scales`` parameter.
+
+        If a string, it should be one of
+        ``['fixed', 'free', 'free_x', 'free_y']``. Currently, only the
+        ``'fixed'`` option is supported.
+
+        Alternatively if a ``dict``, it indicates the relative facet
+        size ratios such as::
+
+            {'x': [1, 2], 'y': [3, 1, 1]}
+
+        This means that in the horizontal direction, the second panel
+        will be twice the length of the first. In the vertical direction
+        the top facet will be the 3 times longer then the second and
+        third facets.
+
+        Note that the number of dimensions in the list must equal the
+        number of facets that will be produced.
+
     shrink : bool
         Whether to shrink the scales to the output of the
         statistics instead of the raw data. Default is ``True``.
@@ -65,13 +81,18 @@ class facet_grid(facet):
     def __init__(self, facets, margins=False, scales='fixed',
                  space='fixed', shrink=True, labeller='label_value',
                  as_table=True, drop=True):
+
         facet.__init__(
             self, scales=scales, shrink=shrink, labeller=labeller,
-            as_table=as_table, drop=drop)
+            as_table=as_table, drop=drop
+        )
+        self.space = space
         self.rows, self.cols = parse_grid_facets(facets)
         self.margins = margins
-        self.space_free = {'x': space in ('free_x', 'free'),
-                           'y': space in ('free_y', 'free')}
+        self.space_free = {
+            'x': isinstance(space, str) and space in ('free_x', 'free'),
+            'y': isinstance(space, str) and space in ('free_y', 'free')
+        }
         self.num_vars_x = len(self.cols)
         self.num_vars_y = len(self.rows)
 
@@ -150,8 +171,6 @@ class facet_grid(facet):
             keys = join_keys(facet_vals, layout, vars)
             data['PANEL'] = match(keys['x'], keys['y'], start=1)
 
-        data = data.sort_values('PANEL', kind='mergesort')
-
         # matching dtype and
         # the categories(panel numbers) for the data should be in the
         # same order as the panels. i.e the panels are the reference,
@@ -173,7 +192,8 @@ class facet_grid(facet):
         nrow = self.nrow
         figure = self.figure
         theme = self.theme
-        get_property = theme.themeables.property
+        aspect_ratio = self._aspect_ratio()
+        _property = theme.themeables.property
 
         left = figure.subplotpars.left
         right = figure.subplotpars.right
@@ -181,27 +201,8 @@ class facet_grid(facet):
         bottom = figure.subplotpars.bottom
         wspace = figure.subplotpars.wspace
         W, H = figure.get_size_inches()
-
-        try:
-            spacing_x = get_property('panel_spacing_x')
-        except KeyError:
-            spacing_x = 0.1
-
-        try:
-            spacing_y = get_property('panel_spacing_y')
-        except KeyError:
-            spacing_y = 0.1
-
-        try:
-            aspect_ratio = get_property('aspect_ratio')
-        except KeyError:
-            # If the panels have different limits the coordinates
-            # cannot compute a common aspect ratio
-            if not self.free['x'] and not self.free['y']:
-                aspect_ratio = self.coordinates.aspect(
-                    self.layout.panel_params[0])
-            else:
-                aspect_ratio = None
+        spacing_x = _property('panel_spacing_x')
+        spacing_y = _property('panel_spacing_y')
 
         # The goal is to have equal spacing along the vertical
         # and the horizontal. We use the wspace and compute
@@ -243,7 +244,7 @@ def parse_grid_facets(facets):
     valid_seqs = ["('var1', '.')", "('var1', 'var2')",
                   "('.', 'var1')", "((var1, var2), (var3, var4))"]
     error_msg_s = ("Valid sequences for specifying 'facets' look like"
-                   " {}".format(valid_seqs))
+                   f" {valid_seqs}")
 
     valid_forms = ['var1 ~ .', 'var1 ~ var2', '. ~ var1',
                    'var1 + var2 ~ var3 + var4',
@@ -251,7 +252,7 @@ def parse_grid_facets(facets):
                    '. ~ func(var1+var3) + func(var2)'
                    ] + valid_seqs
     error_msg_f = ("Valid formula for 'facet_grid' look like"
-                   " {}".format(valid_forms))
+                   f" {valid_forms}")
 
     if isinstance(facets, (tuple, list)):
         if len(facets) != 2:
