@@ -6,7 +6,7 @@ Plotting objects
 from .geom_abline import geom_abline
 from .geom_area import geom_area
 from .geom_bar import geom_bar
-from .geom_bin2d import geom_bin2d
+from .geom_bin_2d import geom_bin_2d, geom_bin2d
 from .geom_blank import geom_blank
 from .geom_boxplot import geom_boxplot
 from .geom_col import geom_col
@@ -27,6 +27,7 @@ from .geom_linerange import geom_linerange
 from .geom_map import geom_map
 from .geom_path import geom_path
 from .geom_point import geom_point
+from .geom_pointdensity import geom_pointdensity
 from .geom_pointrange import geom_pointrange
 from .geom_polygon import geom_polygon
 from .geom_qq import geom_qq
@@ -53,15 +54,15 @@ from .annotation_logticks import annotation_logticks
 from .annotation_stripes import annotation_stripes
 
 
-__all__ = ['geom_abline', 'geom_area', 'geom_bar', 'geom_bin2d',
-           'geom_blank',
+__all__ = ['geom_abline', 'geom_area', 'geom_bar', 'geom_bin_2d',
+           'geom_bin2d', 'geom_blank',
            'geom_boxplot', 'geom_col', 'geom_count', 'geom_crossbar',
            'geom_density', 'geom_density_2d',
            'geom_dotplot', 'geom_errorbar',
            'geom_errorbarh', 'geom_freqpoly', 'geom_histogram',
            'geom_hline', 'geom_jitter', 'geom_label', 'geom_line',
            'geom_linerange', 'geom_map', 'geom_path', 'geom_point',
-           'geom_pointrange', 'geom_pointrange',
+           'geom_pointdensity', 'geom_pointrange',
            'geom_quantile', 'geom_qq', 'geom_qq_line',
            'geom_polygon', 'geom_raster', 'geom_rect',
            'geom_ribbon', 'geom_rug', 'geom_segment', 'geom_sina',
