@@ -4,7 +4,7 @@ import pandas as pd
 
 from ..mapping import aes
 from ..exceptions import PlotnineWarning
-from ..utils import make_iterable, order_as_mapping_data
+from ..utils import make_iterable, order_as_data_mapping
 from ..doctools import document
 from .geom import geom
 from .geom_segment import geom_segment
@@ -29,7 +29,7 @@ class geom_abline(geom):
     legend_geom = 'path'
 
     def __init__(self, mapping=None, data=None, **kwargs):
-        mapping, data = order_as_mapping_data(mapping, data)
+        data, mapping = order_as_data_mapping(data, mapping)
         slope = kwargs.pop('slope', None)
         intercept = kwargs.pop('intercept', None)
 
