@@ -2,7 +2,7 @@ from warnings import warn
 
 import pandas as pd
 
-from ..utils import make_iterable, order_as_mapping_data
+from ..utils import make_iterable, order_as_data_mapping
 from ..exceptions import PlotnineWarning
 from ..doctools import document
 from ..mapping import aes
@@ -29,7 +29,7 @@ class geom_hline(geom):
     legend_geom = 'path'
 
     def __init__(self, mapping=None, data=None, **kwargs):
-        mapping, data = order_as_mapping_data(mapping, data)
+        data, mapping = order_as_data_mapping(data, mapping)
         yintercept = kwargs.pop('yintercept', None)
         if yintercept is not None:
             if mapping:
