@@ -3,7 +3,7 @@ from warnings import warn
 import pandas as pd
 import matplotlib.lines as mlines
 
-from ..utils import make_iterable, SIZE_FACTOR, order_as_mapping_data
+from ..utils import make_iterable, SIZE_FACTOR, order_as_data_mapping
 from ..exceptions import PlotnineWarning
 from ..doctools import document
 from ..mapping import aes
@@ -29,7 +29,7 @@ class geom_vline(geom):
                       'na_rm': False, 'inherit_aes': False}
 
     def __init__(self, mapping=None, data=None, **kwargs):
-        mapping, data = order_as_mapping_data(mapping, data)
+        data, mapping = order_as_data_mapping(data, mapping)
         xintercept = kwargs.pop('xintercept', None)
         if xintercept is not None:
             if mapping:
