@@ -10,7 +10,7 @@ current_theme = None
 base_family = 'Dejavu Sans'
 
 #: Default aspect ratio used by the themes
-aspect_ratio = None
+aspect_ratio = 'auto'
 
 #: Default DPI used by the themes
 dpi = 100
@@ -18,6 +18,15 @@ dpi = 100
 #: Default figure size inches
 figure_size = (640/dpi, 480/dpi)
 
+#: Default parameters for how to tune the subplot layout
+# Choosen to match MPL 2.0 defaults
+SUBPLOTS_ADJUST = {
+    'left': 0.125,  # the left side of the subplots of the figure
+    'right': 0.9,  # the right side of the subplots of the figure
+    'bottom': 0.11,  # the bottom of the subplots of the figure
+    'top': 0.88,  # the top of the subplots of the figure
+}
+
 
 def get_option(name):
     """
@@ -32,7 +41,7 @@ def get_option(name):
 
     if name in {'get_option', 'set_option'} or name not in d:
         from ..exceptions import PlotnineError
-        raise PlotnineError("Unknown option {}".format(name))
+        raise PlotnineError(f"Unknown option {name}")
 
     return d[name]
 
@@ -57,7 +66,7 @@ def set_option(name, value):
 
     if name in {'get_option', 'set_option'} or name not in d:
         from ..exceptions import PlotnineError
-        raise PlotnineError("Unknown option {}".format(name))
+        raise PlotnineError(f"Unknown option {name}")
 
     old = d[name]
     d[name] = value
