@@ -11,6 +11,7 @@ from .theme_minimal import theme_minimal
 from .theme_seaborn import theme_seaborn
 from .theme_void import theme_void
 from .theme_xkcd import theme_xkcd
+from .theme_tufte import theme_tufte
 from .theme import theme_get, theme_set, theme_update
 from .elements import (element_line, element_rect,
                        element_text, element_blank)
@@ -20,7 +21,7 @@ __all__ = ['theme', 'theme_538', 'theme_bw', 'theme_classic',
            'theme_dark', 'theme_gray', 'theme_grey',
            'theme_light', 'theme_linedraw',
            'theme_matplotlib', 'theme_minimal',
-           'theme_seaborn', 'theme_void', 'theme_xkcd',
+           'theme_seaborn', 'theme_void', 'theme_xkcd', 'theme_tufte',
            'theme_get', 'theme_set', 'theme_update',
            'element_line', 'element_rect',
            'element_text', 'element_blank']
