@@ -19,7 +19,7 @@ class theme_light(theme_gray):
 
     def __init__(self, base_size=11, base_family=None):
         theme_gray.__init__(self, base_size, base_family)
-        self.add_theme(theme(
+        self += theme(
             axis_ticks=element_line(color='#B3B3B3', size=0.5),
             axis_ticks_minor=element_blank(),
             legend_key=element_rect(fill='white', color='#7F7F7F', size=0.5),
@@ -28,7 +28,10 @@ class theme_light(theme_gray):
             panel_grid_major=element_line(color='#D9D9D9', size=0.5),
             panel_grid_minor=element_line(color='#EDEDED', size=0.25),
             strip_background=element_rect(
-                fill='#B3B3B3', color='#B3B3B3', size=1),
+                fill='#B3B3B3',
+                color='#B3B3B3',
+                size=1
+            ),
             strip_text_x=element_text(color='white'),
             strip_text_y=element_text(color='white', angle=-90)
-        ), inplace=True)
+        )
