@@ -18,7 +18,7 @@ class theme_linedraw(theme_gray):
 
     def __init__(self, base_size=11, base_family=None):
         theme_gray.__init__(self, base_size, base_family)
-        self.add_theme(theme(
+        self += theme(
             axis_text=element_text(color='black', size=base_size*0.8),
             axis_ticks=element_line(color='black', size=0.5),
             axis_ticks_minor=element_blank(),
@@ -27,8 +27,7 @@ class theme_linedraw(theme_gray):
             panel_border=element_rect(fill='None', color='black', size=1),
             panel_grid_major=element_line(color='black', size=0.1),
             panel_grid_minor=element_line(color='black', size=0.02),
-            strip_background=element_rect(
-                fill='black', color='black', size=1),
+            strip_background=element_rect(fill='black', color='black', size=1),
             strip_text_x=element_text(color='white'),
             strip_text_y=element_text(color='white', angle=-90)
-        ), inplace=True)
+        )
